<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://codecanyon.net/user/kamleshyadav
 * @since      1.0.0
 *
 * @package    Wcreferralscheme
 * @subpackage Wcreferralscheme/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wcreferralscheme
 * @subpackage Wcreferralscheme/admin
 * @author     Kamleshyadav <ajay.shrivas@himanshusofttech.com>
 */
class Wcreferralscheme_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wcreferralscheme_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wcreferralscheme_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wcreferralscheme-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wcreferralscheme_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wcreferralscheme_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wcreferralscheme-admin.js', array( 'jquery' ), $this->version, false );

	}
	
	public function wcreferralscheme_add_section( $sections ) {
	    
	    $sections['referralsetting'] = __( 'Referral Setting', 'wcreferralscheme');
    	return $sections;
	}
   
    function wcreferralscheme_settings_tab() {
       woocommerce_admin_fields(self::wcreferralscheme_get_settings() );
    }
    
   function wcreferralscheme_get_settings() {
    $settings = array(
        'section_title' => array(
            'name'     => __( 'Referral Scheme Setting', 'wcreferralscheme' ),
            'type'     => 'title',
            'desc'     => '',
            'id'       => 'wc_referralsetting_section_title'
            ),
        'referralpoint' => array(
            'name' => __( 'Referral Scheme Point', 'wcreferralscheme' ),
            'type' => 'text',
            'desc' => __( 'Enter Referral Scheme Points in numeric digit', 'wcreferralscheme' ),
            'id'   => 'wc_referralsetting_point'
            ),
        'section_end' => array(
             'type' => 'sectionend',
             'id' => 'wc_referralsetting_section_end'
            )
        );
    return apply_filters( 'wc_referralsetting_settings', $settings );
    }

    function wcreferralscheme_update_settings() {
       woocommerce_update_options(self::wcreferralscheme_get_settings());
    }
     
}
